import os,sys
from gladevcp.persistence import IniFile,widget_defaults,set_debug,select_widgets
import hal
import hal_glib
import gtk
import glib
import linuxcnc
import time

debug = 1

class HandlerClass:
    '''
    class with gladevcp callback handlers
    '''
    def on_pulley_toggled(self,widget,data=None):
        
        if widget.get_active():         
            self.builder.get_object('spindle-rpm-hbar').max = float(self.max_speed_high_gear)
        else:
            self.builder.get_object('spindle-rpm-hbar').max = float(self.max_speed_low_gear)
        self.builder.get_object('spindle-rpm-hbar').queue_draw()
        self.spindle_rpm_hbar_max = self.builder.get_object('spindle-rpm-hbar').max
    def on_destroy(self,obj,data=None):
        self.ini.save_state(self)
 
    def __init__(self, halcomp,builder,useropts):
        '''
        Handler classes are instantiated in the following state:
        - the widget tree is created, but not yet realized (no toplevel window.show() executed yet)
        - the halcomp HAL component is set up and the widhget tree's HAL pins have already been added to it
        - it is safe to add more hal pins because halcomp.ready() has not yet been called at this point.

        after all handlers are instantiated in command line and get_handlers() order, callbacks will be
        connected with connect_signals()/signal_autoconnect()

        The builder may be either of libglade or GtkBuilder type depending on the glade file format.
        '''

        self.halcomp = halcomp
        self.builder = builder
        self.useropts = useropts

        config_ini_file = linuxcnc.ini(os.getenv("INI_FILE_NAME"))
        self.max_speed_high_gear = float(config_ini_file.find("SPINDLE", "MAX_RPM_HIGH") or 0.0)
        self.max_speed_low_gear = float(config_ini_file.find("SPINDLE", "MAX_RPM_LOW") or 0.0)
        print "High Gear: %d" % self.max_speed_high_gear
        print "Low Gear: %d" % self.max_speed_low_gear
 
        self.defaults = {
            IniFile.vars : { 'spindle_rpm_hbar_max' : self.max_speed_high_gear},
            IniFile.widgets: widget_defaults(select_widgets(self.builder.get_objects(), hal_only=True,output_only = True))
        }
        self.ini_filename = __name__ + ".ini"
        print "Ini File Name: %s" % self.ini_filename        
        self.ini = IniFile(self.ini_filename,self.defaults,self.builder)
        self.ini.restore_state(self)
        self.builder.get_object('spindle-rpm-hbar').max= float(self.spindle_rpm_hbar_max)
        self.builder.get_object('spindle-rpm-hbar').queue_draw()
 

def get_handlers(halcomp,builder,useropts):
    '''
    this function is called by gladevcp at import time (when this module is passed with '-u <modname>.py')

    return a list of object instances whose methods should be connected as callback handlers
    any method whose name does not begin with an underscore ('_') is a  callback candidate

    the 'get_handlers' name is reserved - gladevcp expects it, so do not change
    '''
    return [HandlerClass(halcomp,builder,useropts)]
